function[q_day,t_day] = ssmf_subdaily(t_init,ts_func,ks_func,tr_func,zr_func,dt_sat_func,dt_dry_func,alpha_func,n_func,tor_func,inf_pot_func,model_str,a_func)

%% DESCRIPTION INPUTS

% t_init = theta_d;
% ts_func = theta_s;
% ks_func = ks;
% tr_func = theta_r;
% zr_func = zr;
% dt_sat_func = dt_sat;
% dt_dry_func = dt_dry;
% alpha_func = alpha;
% n_func = n;
% tor_func = tor;
% inf_pot_func = inf_pot(d,1);
% model_str = model_wrc_str;

%% DESCRIPTION OUTPUTS

% q_day = vertical flux across zr [m/day]
% t_day = soil water content between the land surface and zr [-]


%%
th_subday(1) = t_init;
s_subday(1) = th_subday(1)*zr_func;

time_step=1;
stop_next_time_step = 0;

inf_pot_temp(1) = inf_pot_func;
% for i_s=0:1:100000
while stop_next_time_step~=1
    inf_temp(time_step) = min(inf_pot_temp(time_step),(ts_func-th_subday(time_step))*zr_func);
    
    % to create an error (results as failed simulation) in the calling function (model_versionBeta3_3_te)
    % in case too much water is being removed
    if ~isreal(th_subday(time_step))
        q_day = 1+1i;
        t_day = 1+1i;
        dt = 1+1i;
        break
    end
    
    % temporary subdaily soil water content and degree of saturation
    th_subday2(time_step) = (th_subday(time_step)*zr_func+inf_temp(time_step))/zr_func;    
    sat(time_step) = (th_subday2(time_step)-tr_func)/(ts_func-tr_func);
    if floor(sat(time_step))==1 % because of the numerical error, sometimes the sat can be slightly over 1. in that case, I equalize it to 1
        th_subday2(time_step) = ts_func;
        sat(time_step) = 1;
    end
    
    % computing time step
    dt(time_step) = (dt_sat_func-dt_dry_func)*sat(time_step)+dt_dry_func;
   
    % stops the subdaily routine if 24 hours have been reached
    if sum(dt)>24
        dt(time_step) = 24-sum(dt(1:end-1));
        stop_next_time_step = 1;
    end
    
    % vertical flux
    [~,k_subday(time_step,1)] = pedotransfer_func('swc',ts_func,alpha_func,n_func,ks_func,th_subday2(time_step),model_str,[tr_func tor_func]); % soil hydraulic conductivity from the pedotransfer function
    if th_subday2(time_step)>=ts_func*0.99 || time_step==1 % for the first subdaily time step
        q_subday(time_step,1) = dt(time_step)/24*k_subday(time_step,1); %divides by 24 because the coeff of modification as to be a correcting factor (dimensionless)
    else
        q_subday(time_step,1) = exp(-a_func.*nansum(q_subday))*dt(time_step)/24*k_subday(time_step,1);
    end
    
    % subroutine storage
    s_subday(time_step+1,1) = th_subday2(time_step)*zr_func-q_subday(time_step,1);    
    th_subday(time_step+1,1) = s_subday(time_step+1,1)/zr_func; % corresponding soil water content    
    sat(time_step+1,1) = (th_subday(time_step+1,1)-tr_func)/(ts_func-tr_func); % degree of saturation
    
    inf_pot_temp(time_step+1) = inf_pot_temp(time_step)-inf_temp(time_step);%q_subday(time_step,1)-(s_subday(time_step+1,1)-s_subday(time_step,1));
    
    % subroutine time step increament
    time_step=time_step+1;    
end

% daily values
t_day = th_subday(end); % daily soil water content is the last soil water content value from the subdaily routine
q_day = sum(q_subday); % daily vertical flux is the sum of the subdaily routine values

